# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'bubble/bclient/ui/wbubble.ui'
#
# Created by: PyQt5 UI code generator 5.8.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_WBubble(object):
    def setupUi(self, WBubble):
        WBubble.setObjectName("WBubble")
        WBubble.resize(838, 922)
        WBubble.setLocale(QtCore.QLocale(QtCore.QLocale.English, QtCore.QLocale.UnitedStates))
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(WBubble)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.tabWidget = QtWidgets.QTabWidget(WBubble)
        self.tabWidget.setObjectName("tabWidget")
        self.serverTab = QtWidgets.QWidget()
        self.serverTab.setObjectName("serverTab")
        self.horizontalLayout_25 = QtWidgets.QHBoxLayout(self.serverTab)
        self.horizontalLayout_25.setObjectName("horizontalLayout_25")
        self.groupBox = QtWidgets.QGroupBox(self.serverTab)
        self.groupBox.setTitle("")
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupBox_4 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_4.setObjectName("groupBox_4")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox_4)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.serverLampLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(21)
        sizePolicy.setVerticalStretch(21)
        sizePolicy.setHeightForWidth(self.serverLampLabel.sizePolicy().hasHeightForWidth())
        self.serverLampLabel.setSizePolicy(sizePolicy)
        self.serverLampLabel.setMinimumSize(QtCore.QSize(21, 21))
        self.serverLampLabel.setMaximumSize(QtCore.QSize(21, 21))
        self.serverLampLabel.setText("")
        self.serverLampLabel.setPixmap(QtGui.QPixmap(":/redbtn"))
        self.serverLampLabel.setScaledContents(True)
        self.serverLampLabel.setAlignment(QtCore.Qt.AlignJustify|QtCore.Qt.AlignVCenter)
        self.serverLampLabel.setObjectName("serverLampLabel")
        self.horizontalLayout_12.addWidget(self.serverLampLabel)
        self.serverStateLabel = QtWidgets.QLabel(self.groupBox_4)
        self.serverStateLabel.setScaledContents(False)
        self.serverStateLabel.setObjectName("serverStateLabel")
        self.horizontalLayout_12.addWidget(self.serverStateLabel)
        self.verticalLayout.addLayout(self.horizontalLayout_12)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.label_10 = QtWidgets.QLabel(self.groupBox_4)
        self.label_10.setObjectName("label_10")
        self.gridLayout.addWidget(self.label_10, 0, 0, 1, 1)
        self.hostLineEdit = QtWidgets.QLineEdit(self.groupBox_4)
        self.hostLineEdit.setObjectName("hostLineEdit")
        self.gridLayout.addWidget(self.hostLineEdit, 0, 1, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.groupBox_4)
        self.label_9.setObjectName("label_9")
        self.gridLayout.addWidget(self.label_9, 1, 0, 1, 1)
        self.portSpinBox = QtWidgets.QSpinBox(self.groupBox_4)
        self.portSpinBox.setMinimum(1025)
        self.portSpinBox.setMaximum(65535)
        self.portSpinBox.setProperty("value", 8587)
        self.portSpinBox.setObjectName("portSpinBox")
        self.gridLayout.addWidget(self.portSpinBox, 1, 1, 1, 1)
        self.speedCheckBox = QtWidgets.QCheckBox(self.groupBox_4)
        self.speedCheckBox.setObjectName("speedCheckBox")
        self.gridLayout.addWidget(self.speedCheckBox, 2, 0, 1, 1)
        self.sspeedCheckBox = QtWidgets.QCheckBox(self.groupBox_4)
        self.sspeedCheckBox.setObjectName("sspeedCheckBox")
        self.gridLayout.addWidget(self.sspeedCheckBox, 2, 1, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout)
        self.verticalLayout_2.addWidget(self.groupBox_4)
        self.groupBox_3 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_3.setObjectName("groupBox_3")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.groupBox_3)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.snblRadio = QtWidgets.QRadioButton(self.groupBox_3)
        self.snblRadio.setObjectName("snblRadio")
        self.horizontalLayout_9.addWidget(self.snblRadio)
        self.dubbleRadio = QtWidgets.QRadioButton(self.groupBox_3)
        self.dubbleRadio.setChecked(True)
        self.dubbleRadio.setObjectName("dubbleRadio")
        self.horizontalLayout_9.addWidget(self.dubbleRadio)
        self.verticalLayout_2.addWidget(self.groupBox_3)
        self.groupBox_2 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.qRadio = QtWidgets.QRadioButton(self.groupBox_2)
        self.qRadio.setChecked(True)
        self.qRadio.setObjectName("qRadio")
        self.horizontalLayout_13.addWidget(self.qRadio)
        self.tthRadio = QtWidgets.QRadioButton(self.groupBox_2)
        self.tthRadio.setObjectName("tthRadio")
        self.horizontalLayout_13.addWidget(self.tthRadio)
        self.verticalLayout_4.addLayout(self.horizontalLayout_13)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.edfCheckBox = QtWidgets.QCheckBox(self.groupBox_2)
        self.edfCheckBox.setObjectName("edfCheckBox")
        self.gridLayout_2.addWidget(self.edfCheckBox, 0, 0, 1, 2)
        self.subdirCheckBox = QtWidgets.QCheckBox(self.groupBox_2)
        self.subdirCheckBox.setObjectName("subdirCheckBox")
        self.gridLayout_2.addWidget(self.subdirCheckBox, 1, 0, 1, 1)
        self.subdirEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.subdirEdit.setEnabled(False)
        self.subdirEdit.setObjectName("subdirEdit")
        self.gridLayout_2.addWidget(self.subdirEdit, 1, 1, 1, 1)
        self.extCheckBox = QtWidgets.QCheckBox(self.groupBox_2)
        self.extCheckBox.setObjectName("extCheckBox")
        self.gridLayout_2.addWidget(self.extCheckBox, 2, 0, 1, 1)
        self.extEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.extEdit.setEnabled(False)
        self.extEdit.setObjectName("extEdit")
        self.gridLayout_2.addWidget(self.extEdit, 2, 1, 1, 1)
        self.multiCheckBox = QtWidgets.QCheckBox(self.groupBox_2)
        self.multiCheckBox.setObjectName("multiCheckBox")
        self.gridLayout_2.addWidget(self.multiCheckBox, 3, 0, 1, 1)
        self.multiEdit = QtWidgets.QLineEdit(self.groupBox_2)
        self.multiEdit.setEnabled(False)
        self.multiEdit.setObjectName("multiEdit")
        self.gridLayout_2.addWidget(self.multiEdit, 3, 1, 1, 1)
        self.verticalLayout_4.addLayout(self.gridLayout_2)
        self.verticalLayout_2.addWidget(self.groupBox_2)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.buttonOptions = QtWidgets.QPushButton(self.groupBox)
        self.buttonOptions.setObjectName("buttonOptions")
        self.horizontalLayout_14.addWidget(self.buttonOptions)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem1)
        self.killServerButton = QtWidgets.QPushButton(self.groupBox)
        self.killServerButton.setObjectName("killServerButton")
        self.horizontalLayout_14.addWidget(self.killServerButton)
        self.stopServerButton = QtWidgets.QPushButton(self.groupBox)
        self.stopServerButton.setObjectName("stopServerButton")
        self.horizontalLayout_14.addWidget(self.stopServerButton)
        self.runServerButton = QtWidgets.QPushButton(self.groupBox)
        self.runServerButton.setObjectName("runServerButton")
        self.horizontalLayout_14.addWidget(self.runServerButton)
        self.verticalLayout_2.addLayout(self.horizontalLayout_14)
        self.horizontalLayout_25.addWidget(self.groupBox)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/redbtn"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.tabWidget.addTab(self.serverTab, icon, "")
        self.saxsTab = QtWidgets.QWidget()
        self.saxsTab.setObjectName("saxsTab")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.saxsTab)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.label_3 = QtWidgets.QLabel(self.saxsTab)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.saxsLampLabel = QtWidgets.QLabel(self.saxsTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(21)
        sizePolicy.setVerticalStretch(21)
        sizePolicy.setHeightForWidth(self.saxsLampLabel.sizePolicy().hasHeightForWidth())
        self.saxsLampLabel.setSizePolicy(sizePolicy)
        self.saxsLampLabel.setMinimumSize(QtCore.QSize(21, 21))
        self.saxsLampLabel.setMaximumSize(QtCore.QSize(21, 21))
        self.saxsLampLabel.setText("")
        self.saxsLampLabel.setPixmap(QtGui.QPixmap(":/redbtn"))
        self.saxsLampLabel.setScaledContents(True)
        self.saxsLampLabel.setAlignment(QtCore.Qt.AlignJustify|QtCore.Qt.AlignVCenter)
        self.saxsLampLabel.setObjectName("saxsLampLabel")
        self.horizontalLayout_3.addWidget(self.saxsLampLabel)
        self.saxsStateLabel = QtWidgets.QLabel(self.saxsTab)
        self.saxsStateLabel.setObjectName("saxsStateLabel")
        self.horizontalLayout_3.addWidget(self.saxsStateLabel)
        self.formLayout.setLayout(0, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout_3)
        self.label_4 = QtWidgets.QLabel(self.saxsTab)
        self.label_4.setObjectName("label_4")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.saxsLastfileLabel = QtWidgets.QLabel(self.saxsTab)
        self.saxsLastfileLabel.setObjectName("saxsLastfileLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.saxsLastfileLabel)
        self.label_8 = QtWidgets.QLabel(self.saxsTab)
        self.label_8.setObjectName("label_8")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_8)
        self.saxsTotalLabel = QtWidgets.QLabel(self.saxsTab)
        self.saxsTotalLabel.setObjectName("saxsTotalLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.saxsTotalLabel)
        self.verticalLayout_6.addLayout(self.formLayout)
        self.line_2 = QtWidgets.QFrame(self.saxsTab)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.verticalLayout_6.addWidget(self.line_2)
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_5 = QtWidgets.QLabel(self.saxsTab)
        self.label_5.setObjectName("label_5")
        self.gridLayout_3.addWidget(self.label_5, 0, 0, 1, 1)
        self.saxsDetectorComboBox = QtWidgets.QComboBox(self.saxsTab)
        self.saxsDetectorComboBox.setObjectName("saxsDetectorComboBox")
        self.saxsDetectorComboBox.addItem("")
        self.saxsDetectorComboBox.addItem("")
        self.gridLayout_3.addWidget(self.saxsDetectorComboBox, 0, 1, 1, 1)
        self.darkFilesButton = QtWidgets.QPushButton(self.saxsTab)
        self.darkFilesButton.setEnabled(False)
        self.darkFilesButton.setObjectName("darkFilesButton")
        self.gridLayout_3.addWidget(self.darkFilesButton, 0, 2, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.saxsTab)
        self.label_12.setObjectName("label_12")
        self.gridLayout_3.addWidget(self.label_12, 1, 0, 1, 1)
        self.saxsFolderButton = QtWidgets.QPushButton(self.saxsTab)
        self.saxsFolderButton.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/folder"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.saxsFolderButton.setIcon(icon1)
        self.saxsFolderButton.setObjectName("saxsFolderButton")
        self.gridLayout_3.addWidget(self.saxsFolderButton, 1, 5, 1, 1)
        self.saxsDirClearButton = QtWidgets.QPushButton(self.saxsTab)
        self.saxsDirClearButton.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/clear"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.saxsDirClearButton.setIcon(icon2)
        self.saxsDirClearButton.setObjectName("saxsDirClearButton")
        self.gridLayout_3.addWidget(self.saxsDirClearButton, 1, 6, 1, 1)
        self.label_16 = QtWidgets.QLabel(self.saxsTab)
        self.label_16.setObjectName("label_16")
        self.gridLayout_3.addWidget(self.label_16, 2, 0, 1, 1)
        self.saxsPoniButton = QtWidgets.QPushButton(self.saxsTab)
        self.saxsPoniButton.setText("")
        self.saxsPoniButton.setIcon(icon1)
        self.saxsPoniButton.setObjectName("saxsPoniButton")
        self.gridLayout_3.addWidget(self.saxsPoniButton, 2, 5, 1, 1)
        self.saxsPoniClearButton = QtWidgets.QPushButton(self.saxsTab)
        self.saxsPoniClearButton.setText("")
        self.saxsPoniClearButton.setIcon(icon2)
        self.saxsPoniClearButton.setObjectName("saxsPoniClearButton")
        self.gridLayout_3.addWidget(self.saxsPoniClearButton, 2, 6, 1, 1)
        self.label_20 = QtWidgets.QLabel(self.saxsTab)
        self.label_20.setObjectName("label_20")
        self.gridLayout_3.addWidget(self.label_20, 3, 0, 1, 1)
        self.saxsMakeMaskButton = QtWidgets.QPushButton(self.saxsTab)
        self.saxsMakeMaskButton.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/mask"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.saxsMakeMaskButton.setIcon(icon3)
        self.saxsMakeMaskButton.setObjectName("saxsMakeMaskButton")
        self.gridLayout_3.addWidget(self.saxsMakeMaskButton, 3, 4, 1, 1)
        self.saxsMaskButton = QtWidgets.QPushButton(self.saxsTab)
        self.saxsMaskButton.setText("")
        self.saxsMaskButton.setIcon(icon1)
        self.saxsMaskButton.setObjectName("saxsMaskButton")
        self.gridLayout_3.addWidget(self.saxsMaskButton, 3, 5, 1, 1)
        self.saxsMaskClearButton = QtWidgets.QPushButton(self.saxsTab)
        self.saxsMaskClearButton.setText("")
        self.saxsMaskClearButton.setIcon(icon2)
        self.saxsMaskClearButton.setObjectName("saxsMaskClearButton")
        self.gridLayout_3.addWidget(self.saxsMaskClearButton, 3, 6, 1, 1)
        self.label_18 = QtWidgets.QLabel(self.saxsTab)
        self.label_18.setObjectName("label_18")
        self.gridLayout_3.addWidget(self.label_18, 4, 0, 1, 1)
        self.saxsBkgButton = QtWidgets.QPushButton(self.saxsTab)
        self.saxsBkgButton.setText("")
        self.saxsBkgButton.setIcon(icon1)
        self.saxsBkgButton.setObjectName("saxsBkgButton")
        self.gridLayout_3.addWidget(self.saxsBkgButton, 4, 5, 1, 1)
        self.saxsBkgClearButton = QtWidgets.QPushButton(self.saxsTab)
        self.saxsBkgClearButton.setText("")
        self.saxsBkgClearButton.setIcon(icon2)
        self.saxsBkgClearButton.setObjectName("saxsBkgClearButton")
        self.gridLayout_3.addWidget(self.saxsBkgClearButton, 4, 6, 1, 1)
        self.label_17 = QtWidgets.QLabel(self.saxsTab)
        self.label_17.setObjectName("label_17")
        self.gridLayout_3.addWidget(self.label_17, 5, 0, 1, 2)
        self.saxsRadialCheckBox = QtWidgets.QCheckBox(self.saxsTab)
        self.saxsRadialCheckBox.setObjectName("saxsRadialCheckBox")
        self.gridLayout_3.addWidget(self.saxsRadialCheckBox, 6, 0, 1, 1)
        self.saxsRadStartSpinBox = QtWidgets.QDoubleSpinBox(self.saxsTab)
        self.saxsRadStartSpinBox.setEnabled(False)
        self.saxsRadStartSpinBox.setMaximum(360.0)
        self.saxsRadStartSpinBox.setObjectName("saxsRadStartSpinBox")
        self.gridLayout_3.addWidget(self.saxsRadStartSpinBox, 6, 1, 1, 1)
        self.label_28 = QtWidgets.QLabel(self.saxsTab)
        self.label_28.setObjectName("label_28")
        self.gridLayout_3.addWidget(self.label_28, 6, 2, 1, 1)
        self.saxsRadStopSpinBox = QtWidgets.QDoubleSpinBox(self.saxsTab)
        self.saxsRadStopSpinBox.setEnabled(False)
        self.saxsRadStopSpinBox.setMaximum(360.0)
        self.saxsRadStopSpinBox.setObjectName("saxsRadStopSpinBox")
        self.gridLayout_3.addWidget(self.saxsRadStopSpinBox, 6, 3, 1, 1)
        self.saxsAzimuthCheckBox = QtWidgets.QCheckBox(self.saxsTab)
        self.saxsAzimuthCheckBox.setObjectName("saxsAzimuthCheckBox")
        self.gridLayout_3.addWidget(self.saxsAzimuthCheckBox, 7, 0, 1, 1)
        self.saxsAziStartSpinBox = QtWidgets.QDoubleSpinBox(self.saxsTab)
        self.saxsAziStartSpinBox.setEnabled(False)
        self.saxsAziStartSpinBox.setMaximum(360.0)
        self.saxsAziStartSpinBox.setObjectName("saxsAziStartSpinBox")
        self.gridLayout_3.addWidget(self.saxsAziStartSpinBox, 7, 1, 1, 1)
        self.labelSaxsAzimuth = QtWidgets.QLabel(self.saxsTab)
        self.labelSaxsAzimuth.setObjectName("labelSaxsAzimuth")
        self.gridLayout_3.addWidget(self.labelSaxsAzimuth, 7, 2, 1, 1)
        self.saxsAziStopSpinBox = QtWidgets.QDoubleSpinBox(self.saxsTab)
        self.saxsAziStopSpinBox.setEnabled(False)
        self.saxsAziStopSpinBox.setMaximum(360.0)
        self.saxsAziStopSpinBox.setObjectName("saxsAziStopSpinBox")
        self.gridLayout_3.addWidget(self.saxsAziStopSpinBox, 7, 3, 1, 1)
        self.saxsSlicesCheckBox = QtWidgets.QCheckBox(self.saxsTab)
        self.saxsSlicesCheckBox.setEnabled(False)
        self.saxsSlicesCheckBox.setObjectName("saxsSlicesCheckBox")
        self.gridLayout_3.addWidget(self.saxsSlicesCheckBox, 7, 4, 1, 2)
        self.saxsMaskLineEdit = QtWidgets.QLineEdit(self.saxsTab)
        self.saxsMaskLineEdit.setObjectName("saxsMaskLineEdit")
        self.gridLayout_3.addWidget(self.saxsMaskLineEdit, 3, 1, 1, 3)
        self.saxsDirLineEdit = QtWidgets.QLineEdit(self.saxsTab)
        self.saxsDirLineEdit.setObjectName("saxsDirLineEdit")
        self.gridLayout_3.addWidget(self.saxsDirLineEdit, 1, 1, 1, 4)
        self.saxsPoniLineEdit = QtWidgets.QLineEdit(self.saxsTab)
        self.saxsPoniLineEdit.setObjectName("saxsPoniLineEdit")
        self.gridLayout_3.addWidget(self.saxsPoniLineEdit, 2, 1, 1, 4)
        self.saxsBkgLineEdit = QtWidgets.QLineEdit(self.saxsTab)
        self.saxsBkgLineEdit.setObjectName("saxsBkgLineEdit")
        self.gridLayout_3.addWidget(self.saxsBkgLineEdit, 4, 1, 1, 4)
        self.saxsBkgCoefSpinBox = QtWidgets.QDoubleSpinBox(self.saxsTab)
        self.saxsBkgCoefSpinBox.setDecimals(4)
        self.saxsBkgCoefSpinBox.setMaximum(1000000.0)
        self.saxsBkgCoefSpinBox.setObjectName("saxsBkgCoefSpinBox")
        self.gridLayout_3.addWidget(self.saxsBkgCoefSpinBox, 5, 2, 1, 2)
        self.verticalLayout_6.addLayout(self.gridLayout_3)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_6.addItem(spacerItem2)
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.saxsPlotButton = QtWidgets.QPushButton(self.saxsTab)
        self.saxsPlotButton.setCheckable(True)
        self.saxsPlotButton.setChecked(False)
        self.saxsPlotButton.setObjectName("saxsPlotButton")
        self.horizontalLayout_20.addWidget(self.saxsPlotButton)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_20.addItem(spacerItem3)
        self.advancedButton = QtWidgets.QPushButton(self.saxsTab)
        self.advancedButton.setObjectName("advancedButton")
        self.horizontalLayout_20.addWidget(self.advancedButton)
        self.runSaxsButton = QtWidgets.QPushButton(self.saxsTab)
        self.runSaxsButton.setObjectName("runSaxsButton")
        self.horizontalLayout_20.addWidget(self.runSaxsButton)
        self.stopSaxsButton = QtWidgets.QPushButton(self.saxsTab)
        self.stopSaxsButton.setObjectName("stopSaxsButton")
        self.horizontalLayout_20.addWidget(self.stopSaxsButton)
        self.verticalLayout_6.addLayout(self.horizontalLayout_20)
        self.tabWidget.addTab(self.saxsTab, icon, "")
        self.waxsTab = QtWidgets.QWidget()
        self.waxsTab.setObjectName("waxsTab")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.waxsTab)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.formLayout_2 = QtWidgets.QFormLayout()
        self.formLayout_2.setObjectName("formLayout_2")
        self.label = QtWidgets.QLabel(self.waxsTab)
        self.label.setObjectName("label")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.waxsLampLabel = QtWidgets.QLabel(self.waxsTab)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(21)
        sizePolicy.setVerticalStretch(21)
        sizePolicy.setHeightForWidth(self.waxsLampLabel.sizePolicy().hasHeightForWidth())
        self.waxsLampLabel.setSizePolicy(sizePolicy)
        self.waxsLampLabel.setMinimumSize(QtCore.QSize(21, 21))
        self.waxsLampLabel.setMaximumSize(QtCore.QSize(21, 21))
        self.waxsLampLabel.setText("")
        self.waxsLampLabel.setPixmap(QtGui.QPixmap(":/redbtn"))
        self.waxsLampLabel.setScaledContents(True)
        self.waxsLampLabel.setAlignment(QtCore.Qt.AlignJustify|QtCore.Qt.AlignVCenter)
        self.waxsLampLabel.setObjectName("waxsLampLabel")
        self.horizontalLayout.addWidget(self.waxsLampLabel)
        self.waxsStateLabel = QtWidgets.QLabel(self.waxsTab)
        self.waxsStateLabel.setObjectName("waxsStateLabel")
        self.horizontalLayout.addWidget(self.waxsStateLabel)
        self.formLayout_2.setLayout(0, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout)
        self.waxsLastfileLabel = QtWidgets.QLabel(self.waxsTab)
        self.waxsLastfileLabel.setObjectName("waxsLastfileLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.waxsLastfileLabel)
        self.label_2 = QtWidgets.QLabel(self.waxsTab)
        self.label_2.setObjectName("label_2")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_2)
        self.label_7 = QtWidgets.QLabel(self.waxsTab)
        self.label_7.setObjectName("label_7")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_7)
        self.waxsTotalLabel = QtWidgets.QLabel(self.waxsTab)
        self.waxsTotalLabel.setObjectName("waxsTotalLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.waxsTotalLabel)
        self.verticalLayout_5.addLayout(self.formLayout_2)
        self.line = QtWidgets.QFrame(self.waxsTab)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout_5.addWidget(self.line)
        self.gridLayout_10 = QtWidgets.QGridLayout()
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.label_55 = QtWidgets.QLabel(self.waxsTab)
        self.label_55.setObjectName("label_55")
        self.gridLayout_10.addWidget(self.label_55, 0, 0, 1, 1)
        self.label_56 = QtWidgets.QLabel(self.waxsTab)
        self.label_56.setObjectName("label_56")
        self.gridLayout_10.addWidget(self.label_56, 1, 0, 1, 1)
        self.waxsPoniClearButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsPoniClearButton.setText("")
        self.waxsPoniClearButton.setIcon(icon2)
        self.waxsPoniClearButton.setObjectName("waxsPoniClearButton")
        self.gridLayout_10.addWidget(self.waxsPoniClearButton, 2, 6, 1, 1)
        self.label_57 = QtWidgets.QLabel(self.waxsTab)
        self.label_57.setObjectName("label_57")
        self.gridLayout_10.addWidget(self.label_57, 2, 0, 1, 1)
        self.waxsDetectorComboBox = QtWidgets.QComboBox(self.waxsTab)
        self.waxsDetectorComboBox.setObjectName("waxsDetectorComboBox")
        self.waxsDetectorComboBox.addItem("")
        self.waxsDetectorComboBox.addItem("")
        self.gridLayout_10.addWidget(self.waxsDetectorComboBox, 0, 1, 1, 1)
        self.label_63 = QtWidgets.QLabel(self.waxsTab)
        self.label_63.setObjectName("label_63")
        self.gridLayout_10.addWidget(self.label_63, 9, 0, 1, 1)
        self.label_59 = QtWidgets.QLabel(self.waxsTab)
        self.label_59.setObjectName("label_59")
        self.gridLayout_10.addWidget(self.label_59, 4, 0, 1, 1)
        self.waxsRadialCheckBox = QtWidgets.QCheckBox(self.waxsTab)
        self.waxsRadialCheckBox.setObjectName("waxsRadialCheckBox")
        self.gridLayout_10.addWidget(self.waxsRadialCheckBox, 7, 0, 1, 1)
        self.waxsBkgClearButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsBkgClearButton.setText("")
        self.waxsBkgClearButton.setIcon(icon2)
        self.waxsBkgClearButton.setObjectName("waxsBkgClearButton")
        self.gridLayout_10.addWidget(self.waxsBkgClearButton, 4, 6, 1, 1)
        self.label_60 = QtWidgets.QLabel(self.waxsTab)
        self.label_60.setObjectName("label_60")
        self.gridLayout_10.addWidget(self.label_60, 5, 0, 1, 2)
        self.waxsMaskButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsMaskButton.setText("")
        self.waxsMaskButton.setIcon(icon1)
        self.waxsMaskButton.setObjectName("waxsMaskButton")
        self.gridLayout_10.addWidget(self.waxsMaskButton, 3, 5, 1, 1)
        self.waxsRadStartSpinBox = QtWidgets.QDoubleSpinBox(self.waxsTab)
        self.waxsRadStartSpinBox.setEnabled(False)
        self.waxsRadStartSpinBox.setMaximum(360.0)
        self.waxsRadStartSpinBox.setObjectName("waxsRadStartSpinBox")
        self.gridLayout_10.addWidget(self.waxsRadStartSpinBox, 7, 1, 1, 1)
        self.label_61 = QtWidgets.QLabel(self.waxsTab)
        self.label_61.setObjectName("label_61")
        self.gridLayout_10.addWidget(self.label_61, 7, 2, 1, 1)
        self.waxsRadStopSpinBox = QtWidgets.QDoubleSpinBox(self.waxsTab)
        self.waxsRadStopSpinBox.setEnabled(False)
        self.waxsRadStopSpinBox.setMaximum(360.0)
        self.waxsRadStopSpinBox.setObjectName("waxsRadStopSpinBox")
        self.gridLayout_10.addWidget(self.waxsRadStopSpinBox, 7, 3, 1, 1)
        self.labelWaxsAzimuth = QtWidgets.QLabel(self.waxsTab)
        self.labelWaxsAzimuth.setObjectName("labelWaxsAzimuth")
        self.gridLayout_10.addWidget(self.labelWaxsAzimuth, 8, 2, 1, 1)
        self.waxsAzimuthCheckBox = QtWidgets.QCheckBox(self.waxsTab)
        self.waxsAzimuthCheckBox.setObjectName("waxsAzimuthCheckBox")
        self.gridLayout_10.addWidget(self.waxsAzimuthCheckBox, 8, 0, 1, 1)
        self.waxsAziStartSpinBox = QtWidgets.QDoubleSpinBox(self.waxsTab)
        self.waxsAziStartSpinBox.setEnabled(False)
        self.waxsAziStartSpinBox.setMaximum(360.0)
        self.waxsAziStartSpinBox.setObjectName("waxsAziStartSpinBox")
        self.gridLayout_10.addWidget(self.waxsAziStartSpinBox, 8, 1, 1, 1)
        self.waxsSlicesCheckBox = QtWidgets.QCheckBox(self.waxsTab)
        self.waxsSlicesCheckBox.setEnabled(False)
        self.waxsSlicesCheckBox.setObjectName("waxsSlicesCheckBox")
        self.gridLayout_10.addWidget(self.waxsSlicesCheckBox, 8, 4, 1, 2)
        self.waxsAziStopSpinBox = QtWidgets.QDoubleSpinBox(self.waxsTab)
        self.waxsAziStopSpinBox.setEnabled(False)
        self.waxsAziStopSpinBox.setMaximum(360.0)
        self.waxsAziStopSpinBox.setObjectName("waxsAziStopSpinBox")
        self.gridLayout_10.addWidget(self.waxsAziStopSpinBox, 8, 3, 1, 1)
        self.waxsMaskLineEdit = QtWidgets.QLineEdit(self.waxsTab)
        self.waxsMaskLineEdit.setObjectName("waxsMaskLineEdit")
        self.gridLayout_10.addWidget(self.waxsMaskLineEdit, 3, 1, 1, 3)
        self.waxsDirLineEdit = QtWidgets.QLineEdit(self.waxsTab)
        self.waxsDirLineEdit.setObjectName("waxsDirLineEdit")
        self.gridLayout_10.addWidget(self.waxsDirLineEdit, 1, 1, 1, 4)
        self.label_58 = QtWidgets.QLabel(self.waxsTab)
        self.label_58.setObjectName("label_58")
        self.gridLayout_10.addWidget(self.label_58, 3, 0, 1, 1)
        self.waxsMakeMaskButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsMakeMaskButton.setText("")
        self.waxsMakeMaskButton.setIcon(icon3)
        self.waxsMakeMaskButton.setObjectName("waxsMakeMaskButton")
        self.gridLayout_10.addWidget(self.waxsMakeMaskButton, 3, 4, 1, 1)
        self.waxsPoniLineEdit = QtWidgets.QLineEdit(self.waxsTab)
        self.waxsPoniLineEdit.setObjectName("waxsPoniLineEdit")
        self.gridLayout_10.addWidget(self.waxsPoniLineEdit, 2, 1, 1, 4)
        self.waxsBkgLineEdit = QtWidgets.QLineEdit(self.waxsTab)
        self.waxsBkgLineEdit.setObjectName("waxsBkgLineEdit")
        self.gridLayout_10.addWidget(self.waxsBkgLineEdit, 4, 1, 1, 4)
        self.label_62 = QtWidgets.QLabel(self.waxsTab)
        self.label_62.setObjectName("label_62")
        self.gridLayout_10.addWidget(self.label_62, 6, 0, 1, 1)
        self.waxsMaskClearButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsMaskClearButton.setText("")
        self.waxsMaskClearButton.setIcon(icon2)
        self.waxsMaskClearButton.setObjectName("waxsMaskClearButton")
        self.gridLayout_10.addWidget(self.waxsMaskClearButton, 3, 6, 1, 1)
        self.waxsBkgButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsBkgButton.setText("")
        self.waxsBkgButton.setIcon(icon1)
        self.waxsBkgButton.setObjectName("waxsBkgButton")
        self.gridLayout_10.addWidget(self.waxsBkgButton, 4, 5, 1, 1)
        self.waxsPoniButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsPoniButton.setText("")
        self.waxsPoniButton.setIcon(icon1)
        self.waxsPoniButton.setObjectName("waxsPoniButton")
        self.gridLayout_10.addWidget(self.waxsPoniButton, 2, 5, 1, 1)
        self.waxsDirClearButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsDirClearButton.setText("")
        self.waxsDirClearButton.setIcon(icon2)
        self.waxsDirClearButton.setObjectName("waxsDirClearButton")
        self.gridLayout_10.addWidget(self.waxsDirClearButton, 1, 6, 1, 1)
        self.waxsDarkFilesButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsDarkFilesButton.setEnabled(False)
        self.waxsDarkFilesButton.setObjectName("waxsDarkFilesButton")
        self.gridLayout_10.addWidget(self.waxsDarkFilesButton, 0, 2, 1, 1)
        self.waxsFolderButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsFolderButton.setText("")
        self.waxsFolderButton.setIcon(icon1)
        self.waxsFolderButton.setObjectName("waxsFolderButton")
        self.gridLayout_10.addWidget(self.waxsFolderButton, 1, 5, 1, 1)
        self.comboNorm = QtWidgets.QComboBox(self.waxsTab)
        self.comboNorm.setObjectName("comboNorm")
        self.comboNorm.addItem("")
        self.comboNorm.addItem("")
        self.comboNorm.addItem("")
        self.gridLayout_10.addWidget(self.comboNorm, 9, 1, 1, 1)
        self.spinWaxsBkgStart = QtWidgets.QDoubleSpinBox(self.waxsTab)
        self.spinWaxsBkgStart.setEnabled(False)
        self.spinWaxsBkgStart.setObjectName("spinWaxsBkgStart")
        self.gridLayout_10.addWidget(self.spinWaxsBkgStart, 9, 2, 1, 1)
        self.spinWaxsBkgStop = QtWidgets.QDoubleSpinBox(self.waxsTab)
        self.spinWaxsBkgStop.setEnabled(False)
        self.spinWaxsBkgStop.setObjectName("spinWaxsBkgStop")
        self.gridLayout_10.addWidget(self.spinWaxsBkgStop, 9, 3, 1, 1)
        self.multiplyLineEdit = QtWidgets.QLineEdit(self.waxsTab)
        self.multiplyLineEdit.setObjectName("multiplyLineEdit")
        self.gridLayout_10.addWidget(self.multiplyLineEdit, 6, 1, 1, 3)
        self.waxsBkgCoefSpinBox = QtWidgets.QDoubleSpinBox(self.waxsTab)
        self.waxsBkgCoefSpinBox.setDecimals(4)
        self.waxsBkgCoefSpinBox.setMaximum(1000000.0)
        self.waxsBkgCoefSpinBox.setObjectName("waxsBkgCoefSpinBox")
        self.gridLayout_10.addWidget(self.waxsBkgCoefSpinBox, 5, 2, 1, 2)
        self.verticalLayout_5.addLayout(self.gridLayout_10)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem4)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.waxsPlotButton = QtWidgets.QPushButton(self.waxsTab)
        self.waxsPlotButton.setCheckable(True)
        self.waxsPlotButton.setChecked(False)
        self.waxsPlotButton.setObjectName("waxsPlotButton")
        self.horizontalLayout_17.addWidget(self.waxsPlotButton)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem5)
        self.runWaxsButton = QtWidgets.QPushButton(self.waxsTab)
        self.runWaxsButton.setObjectName("runWaxsButton")
        self.horizontalLayout_17.addWidget(self.runWaxsButton)
        self.stopWaxsButton = QtWidgets.QPushButton(self.waxsTab)
        self.stopWaxsButton.setObjectName("stopWaxsButton")
        self.horizontalLayout_17.addWidget(self.stopWaxsButton)
        self.verticalLayout_5.addLayout(self.horizontalLayout_17)
        self.tabWidget.addTab(self.waxsTab, icon, "")
        self.verticalLayout_3.addWidget(self.tabWidget)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.aboutButton = QtWidgets.QPushButton(WBubble)
        self.aboutButton.setObjectName("aboutButton")
        self.horizontalLayout_8.addWidget(self.aboutButton)
        self.saveButton = QtWidgets.QPushButton(WBubble)
        self.saveButton.setObjectName("saveButton")
        self.horizontalLayout_8.addWidget(self.saveButton)
        self.loadButton = QtWidgets.QPushButton(WBubble)
        self.loadButton.setObjectName("loadButton")
        self.horizontalLayout_8.addWidget(self.loadButton)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem6)
        self.exitButton = QtWidgets.QPushButton(WBubble)
        self.exitButton.setObjectName("exitButton")
        self.horizontalLayout_8.addWidget(self.exitButton)
        self.verticalLayout_3.addLayout(self.horizontalLayout_8)
        self.label_10.setBuddy(self.hostLineEdit)
        self.label_9.setBuddy(self.portSpinBox)
        self.label_20.setBuddy(self.saxsMaskLineEdit)
        self.label_58.setBuddy(self.saxsMaskLineEdit)

        self.retranslateUi(WBubble)
        self.tabWidget.setCurrentIndex(0)
        self.comboNorm.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(WBubble)
        WBubble.setTabOrder(self.tabWidget, self.hostLineEdit)
        WBubble.setTabOrder(self.hostLineEdit, self.portSpinBox)
        WBubble.setTabOrder(self.portSpinBox, self.speedCheckBox)
        WBubble.setTabOrder(self.speedCheckBox, self.sspeedCheckBox)
        WBubble.setTabOrder(self.sspeedCheckBox, self.snblRadio)
        WBubble.setTabOrder(self.snblRadio, self.dubbleRadio)
        WBubble.setTabOrder(self.dubbleRadio, self.qRadio)
        WBubble.setTabOrder(self.qRadio, self.tthRadio)
        WBubble.setTabOrder(self.tthRadio, self.edfCheckBox)
        WBubble.setTabOrder(self.edfCheckBox, self.subdirCheckBox)
        WBubble.setTabOrder(self.subdirCheckBox, self.subdirEdit)
        WBubble.setTabOrder(self.subdirEdit, self.extCheckBox)
        WBubble.setTabOrder(self.extCheckBox, self.extEdit)
        WBubble.setTabOrder(self.extEdit, self.multiCheckBox)
        WBubble.setTabOrder(self.multiCheckBox, self.multiEdit)
        WBubble.setTabOrder(self.multiEdit, self.buttonOptions)
        WBubble.setTabOrder(self.buttonOptions, self.killServerButton)
        WBubble.setTabOrder(self.killServerButton, self.stopServerButton)
        WBubble.setTabOrder(self.stopServerButton, self.runServerButton)
        WBubble.setTabOrder(self.runServerButton, self.aboutButton)
        WBubble.setTabOrder(self.aboutButton, self.saveButton)
        WBubble.setTabOrder(self.saveButton, self.loadButton)
        WBubble.setTabOrder(self.loadButton, self.exitButton)
        WBubble.setTabOrder(self.exitButton, self.saxsPlotButton)
        WBubble.setTabOrder(self.saxsPlotButton, self.advancedButton)
        WBubble.setTabOrder(self.advancedButton, self.runSaxsButton)
        WBubble.setTabOrder(self.runSaxsButton, self.stopSaxsButton)
        WBubble.setTabOrder(self.stopSaxsButton, self.stopWaxsButton)
        WBubble.setTabOrder(self.stopWaxsButton, self.saxsDetectorComboBox)
        WBubble.setTabOrder(self.saxsDetectorComboBox, self.waxsPlotButton)
        WBubble.setTabOrder(self.waxsPlotButton, self.runWaxsButton)
        WBubble.setTabOrder(self.runWaxsButton, self.darkFilesButton)
        WBubble.setTabOrder(self.darkFilesButton, self.saxsFolderButton)
        WBubble.setTabOrder(self.saxsFolderButton, self.saxsDirClearButton)
        WBubble.setTabOrder(self.saxsDirClearButton, self.saxsPoniButton)
        WBubble.setTabOrder(self.saxsPoniButton, self.saxsPoniClearButton)
        WBubble.setTabOrder(self.saxsPoniClearButton, self.saxsMakeMaskButton)
        WBubble.setTabOrder(self.saxsMakeMaskButton, self.saxsMaskButton)
        WBubble.setTabOrder(self.saxsMaskButton, self.saxsMaskClearButton)
        WBubble.setTabOrder(self.saxsMaskClearButton, self.saxsBkgButton)
        WBubble.setTabOrder(self.saxsBkgButton, self.saxsBkgClearButton)
        WBubble.setTabOrder(self.saxsBkgClearButton, self.saxsRadialCheckBox)
        WBubble.setTabOrder(self.saxsRadialCheckBox, self.saxsRadStartSpinBox)
        WBubble.setTabOrder(self.saxsRadStartSpinBox, self.saxsRadStopSpinBox)
        WBubble.setTabOrder(self.saxsRadStopSpinBox, self.saxsAzimuthCheckBox)
        WBubble.setTabOrder(self.saxsAzimuthCheckBox, self.saxsAziStartSpinBox)
        WBubble.setTabOrder(self.saxsAziStartSpinBox, self.saxsAziStopSpinBox)
        WBubble.setTabOrder(self.saxsAziStopSpinBox, self.saxsSlicesCheckBox)
        WBubble.setTabOrder(self.saxsSlicesCheckBox, self.saxsMaskLineEdit)
        WBubble.setTabOrder(self.saxsMaskLineEdit, self.saxsDirLineEdit)
        WBubble.setTabOrder(self.saxsDirLineEdit, self.saxsPoniLineEdit)
        WBubble.setTabOrder(self.saxsPoniLineEdit, self.saxsBkgLineEdit)
        WBubble.setTabOrder(self.saxsBkgLineEdit, self.saxsBkgCoefSpinBox)

    def retranslateUi(self, WBubble):
        _translate = QtCore.QCoreApplication.translate
        WBubble.setWindowTitle(_translate("WBubble", "Bubble client"))
        self.groupBox_4.setTitle(_translate("WBubble", "Server"))
        self.serverStateLabel.setText(_translate("WBubble", "Server is stopped"))
        self.label_10.setText(_translate("WBubble", "Server &host"))
        self.hostLineEdit.setText(_translate("WBubble", "localhost"))
        self.label_9.setText(_translate("WBubble", "Server &port"))
        self.speedCheckBox.setText(_translate("WBubble", "Optimize &for speed (no images)"))
        self.sspeedCheckBox.setText(_translate("WBubble", "Super speed (&no control)"))
        self.groupBox_3.setTitle(_translate("WBubble", "Beamline"))
        self.snblRadio.setText(_translate("WBubble", "&SNBL"))
        self.dubbleRadio.setText(_translate("WBubble", "&Dubble"))
        self.groupBox_2.setTitle(_translate("WBubble", "Output"))
        self.qRadio.setText(_translate("WBubble", "&Q (nm⁻ⁱ)"))
        self.tthRadio.setText(_translate("WBubble", "&2θ⁰"))
        self.edfCheckBox.setText(_translate("WBubble", "Normalized EDF"))
        self.subdirCheckBox.setText(_translate("WBubble", "Subfolder"))
        self.extCheckBox.setText(_translate("WBubble", "Extension"))
        self.multiCheckBox.setText(_translate("WBubble", "Multicolumn"))
        self.buttonOptions.setText(_translate("WBubble", "Options"))
        self.killServerButton.setText(_translate("WBubble", "Stop server"))
        self.stopServerButton.setText(_translate("WBubble", "Disconnect"))
        self.runServerButton.setText(_translate("WBubble", "Connect"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.serverTab), _translate("WBubble", "Server"))
        self.label_3.setText(_translate("WBubble", "State:"))
        self.saxsStateLabel.setText(_translate("WBubble", "stopped"))
        self.label_4.setText(_translate("WBubble", "Last file:"))
        self.saxsLastfileLabel.setText(_translate("WBubble", "unknown"))
        self.label_8.setText(_translate("WBubble", "Total:"))
        self.saxsTotalLabel.setText(_translate("WBubble", "0"))
        self.label_5.setText(_translate("WBubble", "Detector"))
        self.saxsDetectorComboBox.setItemText(0, _translate("WBubble", "Pilatus"))
        self.saxsDetectorComboBox.setItemText(1, _translate("WBubble", "Frelon"))
        self.darkFilesButton.setText(_translate("WBubble", "Dark files"))
        self.label_12.setText(_translate("WBubble", "Folder"))
        self.label_16.setText(_translate("WBubble", "Poni"))
        self.label_20.setText(_translate("WBubble", "&Mask"))
        self.label_18.setText(_translate("WBubble", "Background"))
        self.label_17.setText(_translate("WBubble", "Background coefficient"))
        self.saxsRadialCheckBox.setText(_translate("WBubble", "Radial start"))
        self.label_28.setText(_translate("WBubble", "and stop"))
        self.saxsAzimuthCheckBox.setText(_translate("WBubble", "Azimuth start"))
        self.labelSaxsAzimuth.setText(_translate("WBubble", "and stop"))
        self.saxsSlicesCheckBox.setText(_translate("WBubble", "slices"))
        self.saxsPlotButton.setText(_translate("WBubble", "Plot"))
        self.advancedButton.setText(_translate("WBubble", "Advanced"))
        self.runSaxsButton.setText(_translate("WBubble", "Run SAXS"))
        self.stopSaxsButton.setText(_translate("WBubble", "Stop SAXS"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.saxsTab), _translate("WBubble", "SAXS"))
        self.label.setText(_translate("WBubble", "State:"))
        self.waxsStateLabel.setText(_translate("WBubble", "stopped"))
        self.waxsLastfileLabel.setText(_translate("WBubble", "unknown"))
        self.label_2.setText(_translate("WBubble", "Last file:"))
        self.label_7.setText(_translate("WBubble", "Total:"))
        self.waxsTotalLabel.setText(_translate("WBubble", "0"))
        self.label_55.setText(_translate("WBubble", "Detector"))
        self.label_56.setText(_translate("WBubble", "Folder"))
        self.label_57.setText(_translate("WBubble", "Poni"))
        self.waxsDetectorComboBox.setItemText(0, _translate("WBubble", "Pilatus"))
        self.waxsDetectorComboBox.setItemText(1, _translate("WBubble", "Frelon"))
        self.label_63.setText(_translate("WBubble", "Normalize"))
        self.label_59.setText(_translate("WBubble", "Background"))
        self.waxsRadialCheckBox.setText(_translate("WBubble", "Radial start"))
        self.label_60.setText(_translate("WBubble", "Background coefficient"))
        self.label_61.setText(_translate("WBubble", "and stop"))
        self.labelWaxsAzimuth.setText(_translate("WBubble", "and stop"))
        self.waxsAzimuthCheckBox.setText(_translate("WBubble", "Azimuth start"))
        self.waxsSlicesCheckBox.setText(_translate("WBubble", "slices"))
        self.label_58.setText(_translate("WBubble", "&Mask"))
        self.label_62.setText(_translate("WBubble", "Multiply"))
        self.waxsDarkFilesButton.setText(_translate("WBubble", "Dark files"))
        self.comboNorm.setItemText(0, _translate("WBubble", "None"))
        self.comboNorm.setItemText(1, _translate("WBubble", "Monitor"))
        self.comboNorm.setItemText(2, _translate("WBubble", "Bkg"))
        self.waxsPlotButton.setText(_translate("WBubble", "Plot"))
        self.runWaxsButton.setText(_translate("WBubble", "Run WAXS"))
        self.stopWaxsButton.setText(_translate("WBubble", "Stop WAXS"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.waxsTab), _translate("WBubble", "WAXS"))
        self.aboutButton.setText(_translate("WBubble", "About"))
        self.saveButton.setText(_translate("WBubble", "Save..."))
        self.loadButton.setText(_translate("WBubble", "Load..."))
        self.exitButton.setText(_translate("WBubble", "Exit"))

from . import resources_rc
